# Changes

Version 1.1.2.post1 (2020-08-06)

We closed a total of 24 issues (enhancements and bug fixes) through 8 pull requests, since our last release on 2020-02-24.

## Issues Closed
  - fix doctest of check_constant (#48)
  - Fixed Effects Panel - Spatial Lag model (#42)
  - Fixed Effects Panel - Spatial Lag (#41)
  - Removing unused spat_diag argument. (#43)
  - Remove `spat_diag` options altogether for `ML_Lag` & `ML_Error` or document they're ignored (#13)
  - spreg 1.1.0 was not released on pypi? (#26)
  - spreg GitHub home needs title (#29)
  - transfer of closed pr from pysal-meta (#18)
  - transfer of closed pr in pysal-meta to pysal/spreg (#17)
  - Rebasing panel (#40)
  - branch "panel" for gsoc 2020 (#39)
  - Updates on all spreg functions (#37)
  - Adding spatial panels: KKP (#31)
  - ml_lag example failing? (#33)
  - release prep (#36)
  - Allowing single dimensions array as y and fixing BaseGM_Lag (#35)

## Pull Requests
  - fix doctest of check_constant (#48)
  - Fixed Effects Panel - Spatial Lag (#41)
  - Removing unused spat_diag argument. (#43)
  - Rebasing panel (#40)
  - branch "panel" for gsoc 2020 (#39)
  - Updates on all spreg functions (#37)
  - release prep (#36)
  - Allowing single dimensions array as y and fixing BaseGM_Lag (#35)

The following individuals contributed to this release:

  - Pedro Amaral
  - Wei Kang
  - Eli Knaap